package dev.fitko.fitconnect.client.steps.subscriber;

import dev.fitko.fitconnect.api.domain.model.destination.Destination;
import dev.fitko.fitconnect.api.domain.model.event.EventLogEntry;
import dev.fitko.fitconnect.api.domain.model.metadata.Metadata;
import dev.fitko.fitconnect.api.domain.model.metadata.attachment.Attachment;
import dev.fitko.fitconnect.api.domain.model.metadata.data.Data;
import dev.fitko.fitconnect.api.domain.model.submission.SubmissionForPickup;
import dev.fitko.fitconnect.api.services.Subscriber;

import java.util.List;
import java.util.Set;
import java.util.UUID;

public interface RequestSubmissionStep {

    /**
     * Loads a list of available {@link SubmissionForPickup} that were submitted to the {@link Subscriber}.
     *
     * @param destinationId unique identifier for a destination
     * @param offset        position in the dataset
     * @param limit         number of submissions in result (max. is 500)
     * @return set of unique of available submissions for pickup
     */
    Set<SubmissionForPickup> getAvailableSubmissions(UUID destinationId, int offset, int limit);

    /**
     * Loads a list of available {@link SubmissionForPickup} that were submitted to the {@link Subscriber}.
     *
     * @param destinationId unique identifier for a destination
     * @return set of unique available submissions for pickup
     */
    Set<SubmissionForPickup> getAvailableSubmissions(UUID destinationId);

    /**
     * Loads a single {@link SubmissionForPickup} by id.
     *
     * @param submissionId unique identifier of a {@link SubmissionForPickup}
     * @return next step to load availbale {@link Metadata}, {@link Data} and {@link Attachment}s
     */
    ConfirmSubmissionStep requestSubmission(UUID submissionId);

    /**
     * Retrieve the entire event log for a submissions caseId of a specific destination.
     *
     * @param caseId unique identifier of the case the log should be retrieved for
     * @param destinationId unique identifier of the {@link Destination} the log should be retrieved for
     *
     * @return List of {@link EventLogEntry}s for the given case
     */
    List<EventLogEntry> getEventLog(UUID caseId, UUID destinationId);
}
